;-----------------------------------------------------------------------------
;* Musterprogramm fuer AVR-Assembler (avra)       letzte Aenderung: 4.3.2014
;* Version: 0.0
;* Prozessor: ATtiny10, ATtiny85
;* Schaltschema: Port B0,B1,B2 mit LEDs verbunden
;* Autor: Rolf Pfister
;* Copyright: Freeware
;* History:
;* 4.3.2014	Erstellung aus entsprechendem Musterprog. fuer Tiny13A
;*
;-----------------------------------------------------------------------------

;; Hier Typ auswaehlen:
.equ TINY10=1
;.equ TINY85=1

;-----------------------------------------------------------------------------
.ifdef TINY10
	.include "tn10def.inc" 	; Definitionsdatei fuer den Prozessortyp
; Reset und Interruptvectoren	;Adr. Beschreibung
begin:	rjmp	main		; 0   Power On Reset
	reti			; 1   INT0
	reti			; 2   PCINT0
	reti			; 3   Timer0 Capture
	reti			; 4   Timer0 Overflow
	reti			; 5   Timer0 CompareA
	reti			; 6   Timer0 CompareB
	reti			; 7   Analog Comparator (ANA_COMP)
	reti			; 8   Watchdog Interrupt (WDT)
	reti			; 9   Voltage Level Monitor (VLM)
	reti			; A   ADC Conversion
.endif
.ifdef TINY85
	.include "tn85def.inc" 	; Definitionsdatei fuer den Prozessortyp
; Reset und Interruptvectoren	;Adr. Beschreibung
begin:	rjmp	main		; 0   Power On Reset
	reti			; 1   INT0
	reti			; 2   PCINT0
	reti			; 3   Timer1 CompA
	reti			; 4   Timer1 Overflow
	reti			; 5   Timer0 Overflow
	reti			; 6   EEPROM Ready
	reti			; 7   Analog Comparator (ANA_COMP)
	reti			; 8   ADC Conversion Complete
	reti			; 9   Timer1 CompB
	reti			; A   Timer0 CompA
	reti			; B   Timer0 CompB
	reti			; C   WatchDog Time-out
	reti			; D   USI Start
	reti			; E   USI Overflow
.endif
;-----------------------------------------------------------------------------
; Start, Power On, Reset
main:	ldi r16, low(RAMEND)
        out SPL, r16  	     ; Init Stackpointer
.ifdef TINY85
	ldi r16, high(RAMEND)
        out SPH, r16  	     ; Init Stackpointer
.endif

;; Init-Code
	ldi r16, 0x07
        out DDRB, r16	    ; B0-B2 als Ausgaenge
        ldi r16, 1
        out PORTB, r16      ; erste LED einschalten
	ldi r20, 5

;; Test um CPU-Frequenz zu messen:
;t0:	inc r16			;binaer zaehlen
;	out PORTB, r16		;LEDs blinken lassen
;	rjmp t0			;diese Schlaufe braucht 4 Takte
				;gemessene Frequenz an PB0 ist also f/8

;-----------------------------------------------------------------------------
	ldi r17, 1
	clr r18
mainloop:
	add r24, r17
	adc r25, r18
	brcc mainloop		;Warteschlaufe
	subi r20, 1
	brne mainloop		;noch eine Warteschlaufe
	ldi r20, 5
	
	rol r16			;Rotiere Links
	cpi r16,0x08
	brne t1
	ldi r16, 1
t1:	out PORTB, r16		;LEDs blinken lassen
	rjmp mainloop
